"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const utils_1 = require("../utils");
exports.default = (options) => {
    return schematics_1.chain([
        addDependencies,
        addCommitlintConfigFile,
        addHuskyConfig,
        addCommitizenConfig,
        addNpmRunScript,
        options.skipInstall ? schematics_1.noop() : installDependencies,
    ]);
};
const addDependencies = () => (tree, context) => {
    context.logger.info('Added npm packages as dev dependencies');
    const packageJson = utils_1.getPackageJson(tree);
    const devDepsToAdd = {
        '@commitlint/cli': '^8.2.0',
        '@commitlint/config-angular': '^8.2.0',
        commitizen: '^4.0.3',
        'cz-conventional-changelog': '^3.0.2',
        husky: '^3.0.9',
        'standard-version': '^7.0.0',
    };
    packageJson.devDependencies = Object.assign({}, devDepsToAdd, packageJson.devDependencies);
    utils_1.overwritePackageJson(tree, packageJson);
};
const addNpmRunScript = () => (tree, context) => {
    context.logger.info('Added npm script for release');
    const packageJson = utils_1.getPackageJson(tree);
    const scriptsToAdd = {
        release: 'standard-version',
    };
    packageJson.scripts = Object.assign({}, scriptsToAdd, packageJson.scripts);
    utils_1.overwritePackageJson(tree, packageJson);
};
const addHuskyConfig = () => (tree, context) => {
    context.logger.info('Added husky configuration');
    const packageJson = utils_1.getPackageJson(tree);
    const huskyConfig = {
        hooks: {
            'commit-msg': 'commitlint -E HUSKY_GIT_PARAMS',
        },
    };
    packageJson.husky = Object.assign({}, huskyConfig, packageJson.husky);
    utils_1.overwritePackageJson(tree, packageJson);
};
const addCommitizenConfig = () => (tree, context) => {
    context.logger.info('Added commitizen configuration');
    const packageJson = utils_1.getPackageJson(tree);
    const commitizenConfig = {
        commitizen: {
            path: './node_modules/cz-conventional-changelog',
        },
    };
    packageJson.config = Object.assign({}, commitizenConfig, packageJson.config);
    utils_1.overwritePackageJson(tree, packageJson);
};
const addCommitlintConfigFile = () => (tree, context) => {
    context.logger.info('Added commitlint configuration file');
    const sourceTemplates = schematics_1.url('./files');
    const sourceParameterizedTemplates = schematics_1.apply(sourceTemplates, [schematics_1.template({})]);
    return schematics_1.mergeWith(sourceParameterizedTemplates)(tree, context);
};
const installDependencies = () => (_tree, context) => {
    context.logger.info('Installs npm dependencies');
    context.addTask(new tasks_1.NodePackageInstallTask());
};
//# sourceMappingURL=index.js.map