"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const schematics_1 = require("@angular-devkit/schematics");
const testing_1 = require("@angular-devkit/schematics/testing");
const test_1 = require("@schematics/angular/utility/test");
describe('ngx-semantic-version schematic', () => {
    const schematicRunner = new testing_1.SchematicTestRunner('ngx-semantic-version', path_1.resolve(__dirname, '../collection.json'));
    const project = 'foo';
    const defaultOptions = {
        skipInstall: false,
    };
    let appTree;
    beforeEach(() => __awaiter(this, void 0, void 0, function* () {
        appTree = new testing_1.UnitTestTree(new schematics_1.HostTree());
        appTree = yield setupProject(appTree, schematicRunner, project);
    }));
    describe('when using the default options', () => {
        beforeEach(() => __awaiter(this, void 0, void 0, function* () {
            appTree = yield schematicRunner
                .runSchematicAsync('ng-add', defaultOptions, appTree)
                .toPromise();
        }));
        it('should add the commitlint configuration file', () => {
            expect(appTree.files).toContain('/commitlint.config.js');
        });
        it('should add all required dependencies to the package.json', () => {
            const packageJsonPath = '/package.json';
            expect(appTree.files).toContain(packageJsonPath);
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            const { devDependencies } = packageJson;
            expect(devDependencies['@commitlint/cli']).toBeDefined();
            expect(devDependencies['@commitlint/config-angular']).toBeDefined();
            expect(devDependencies.commitizen).toBeDefined();
            expect(devDependencies['cz-conventional-changelog']).toBeDefined();
            expect(devDependencies.husky).toBeDefined();
            expect(devDependencies['standard-version']).toBeDefined();
        });
        it('should add a npm run script', () => {
            const packageJsonPath = '/package.json';
            expect(appTree.files).toContain(packageJsonPath);
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            const { scripts } = packageJson;
            expect(scripts.release).toEqual('standard-version');
        });
        it('should add the husky configuration', () => {
            const packageJsonPath = '/package.json';
            expect(appTree.files).toContain(packageJsonPath);
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            const { husky } = packageJson;
            expect(husky.hooks['commit-msg']).toEqual('commitlint -E HUSKY_GIT_PARAMS');
        });
        it('should add the commitizen configuration', () => {
            const packageJsonPath = '/package.json';
            expect(appTree.files).toContain(packageJsonPath);
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            const { config } = packageJson;
            expect(config.commitizen.path).toEqual('./node_modules/cz-conventional-changelog');
        });
    });
});
function setupProject(tree, schematicRunner, name) {
    return __awaiter(this, void 0, void 0, function* () {
        tree = yield schematicRunner
            .runExternalSchematicAsync('@schematics/angular', 'workspace', {
            name: 'workspace',
            version: '8.0.0',
            newProjectRoot: '',
        })
            .toPromise();
        tree = yield schematicRunner
            .runExternalSchematicAsync('@schematics/angular', 'application', {
            name,
            projectRoot: '',
        }, tree)
            .toPromise();
        return tree;
    });
}
//# sourceMappingURL=index_spec.js.map